@@ -1,5 +1,7 @@
 import pandas as pd
 
+from pymeos.io import DeserializerFloat
+from pymeos.temporal import TFloatInst, TFloatSeq
 from sqlalchemy.types import UserDefinedType
 from pandas.api.types import is_numeric_dtype
 
@@ -7,6 +9,10 @@ from .TBaseType import TBaseType
 
 
 class TFloat(TBaseType):
+    pymeos_sequence_type = TFloatSeq
+    pymeos_instant_type = TFloatInst
+    pymeos_deserializer_type = DeserializerFloat
+
     def get_col_spec(self):
         return "TFLOAT"
 
@@ -17,11 +23,3 @@ class TFloat(TBaseType):
             raise TypeError(
                 "TInt needs int values. Got: {} Expected {}".format(dtypes.kind, "f")
             )
-
-    @staticmethod
-    def write_instant_value(value):
-        return str(value)
-
-    @staticmethod
-    def parse_instant_value(value):
-        return float(value)
